---
title: LibreNMS adapter
---

import ReferenceLink from "../../src/components/Card";
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

<!-- vale off -->
## What is LibreNMS?
<!-- vale on -->

LibreNMS is an open-source network monitoring system that automatically discovers, monitors, and alerts on your network devices using pre-configured setups, providing comprehensive insights for proactive network management.

## Sync directions supported

- LibreNMS → Infrahub

:::info

Currently, the LibreNMS adapter supports only **one-way synchronization** from LibreNMS to Infrahub.
Syncing data back into LibreNMS is not yet supported.

:::

:::warning Under Construction
:::